### R code from vignette source 'Vaccine.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Vaccine.Rnw:6-8
###################################################
library(CellCODE)
library(RColorBrewer)


###################################################
### code chunk number 2: Vaccine.Rnw:14-17
###################################################
data("GSE29619")
data("GSE29619facts")
data("IRIS")


###################################################
### code chunk number 3: Vaccine.Rnw:20-27
###################################################
irisTag=tagData(IRIS[,c("Neutrophil-Resting","CD4Tcell-N0", 
                        "Monocyte-Day0", "Bcell-naïve",
                        "NKcell-control", "PlasmaCell-FromPBMC", "DendriticCell-LPSstimulated")],2, max=20, 
                ref=GSE29619, ref.mean=F);
colnames(irisTag)=c("Neutrophil","Tcell", "Monocyte", 
                    "Bcell", "NKcell", "PlasmaCell", "DendriticCell" )



###################################################
### code chunk number 4: Vaccine.Rnw:32-33
###################################################
SPVs=getAllSPVs(GSE29619, paste(GSE29619.facts[,"vaccine"], GSE29619.facts[,"time"]), irisTag, "mixed", T) 


###################################################
### code chunk number 5: Vaccine.Rnw:39-44
###################################################
#load the FCM data
data("fcm")
ii7v=which(GSE29619.facts[,3]=="D7")
plot(fcm[ii7v,3], SPVs[ii7v,6], log="x", ylab="Plasma Cell SPV", xlab="Plasmablast fraction (in percent)", pch=19)



###################################################
### code chunk number 6: Vaccine.Rnw:49-51
###################################################

SPVsR=t(resid(t(SPVs), model.matrix(~0+as.factor(GSE29619.facts[,2]))))


###################################################
### code chunk number 7: Vaccine.Rnw:53-60
###################################################
par(mfrow=c(2,3), mai=c(1,0.4,0.4,0.1), omi=rep(0,4))

for ( i in c(2:7)){
  boxplot(SPVsR[,i]~as.factor(paste(GSE29619.facts[,4],GSE29619.facts[,3])), outline=F, density=c(10,20,300),  las=2, yaxt="n", col=c(brewer.pal(3,"Blues"), brewer.pal(3, "Oranges")), density=c(10,20,300), at=c(1,2,3,5,6,7))
  title(colnames(irisTag)[i])
}



